x='proa_V.dat';
z='V';
leaflet='top';
ti=0;
tt=150;
bt=16.02;
Res1=321;
Res2=332;
RNAME='AGAIKLGDFNLI';

%Required input variables:
%1 x-a string '' that names a text document containg the protein positions
%2 z-a string '' that partially will be used to name and title figures
%3 ti- |initial time| of the simulation (in case the data file begins 
%half way through the simulation: e.g. 100ns or 0ns more commonly)
%4 tt- |total time| of the the simulation.
%If data file goes from 0 ns to 50 ns value would be the number 50.
%If data file goes from 100ns to 150ns value would be the number 50.
%5 bt- |binding time| time at which membrane-molecule contact is achieved
%This value defines the time frame of the two histogram figures
%could be specified as any number within the simulation time.
%6 Res1 the residue ID of the first residue selected from the molecule
%7 Res2 the residue ID of the last residue selected from the molecule
%
%
%Extra notes: Please input rounded times for the binding times because
%if the counter variables get decimals then the plots will fail try to make
%sure 

%Purpose: Graphically represent the interactions between the lipid domain
%and outside molecules of interest. This is achieved by plotting the
%vertical distances of different variables vs time:
%1)All selected residue positions vs time with a reference to the membrane
%2)Sequentially averaging the first half of the residues in the set and then 
    %averaging the second half of residues in the set
    %(Useful to see analyze the tilt of loops joining two helixes)
%3)The Minimum position of all the selected residues vs time
%4)Color coded version of step 3, to show which specific residues are
    %closest at different times
%5)Histograms- frequency of which residues were closest to the membrane
   %This analysis is then split into two parts, before and after binding.


H=Res1:Res2;
HHH=size(H);
HHH=HHH(1,2);

%Call it like TilePlots('proa_V.dat', 'V', 100, 50, 100, 322,333 )

%Importing protein position data from user defined input file
A=importdata(x);
A=abs((A(:,3)));
U=size(A);
U=U(1,1);
Ul=0:HHH:U;
D=size(Ul);
o=zeros(HHH,D(1,2)-1);
o=A(1:HHH*1,:);
%Organizing the data from the input file
for i =2:D(1,2)-1   
o=[o A(Ul(1,i)+1:(HHH*i),:)];
i=i+1;
end

%Defining an important internal variable named w
w=size(o);
w=w(1,2);

wscatter=size(o(1,ti*100+1:tt*100+ti*100));
wscatter=wscatter(1,2);
%Here the time is defined based off user inputs
a=2*(w-1)/tt;
b=(tt)/(w-1);
t=(ti):b:(((2*(w-1)/a))+ti);

%Another internal variable generated, user should follow the naming
%convention so that matlab can import the correct file

%A stores the variable containing the position of the membrane marker
%This data is an average for every frame while the protein data was 12
%numbers for every data point
%the second element in the matrix size(o) divided by the first element in 
%size(A2) shows that there is one

%This defines the information for the location of the lipids
if(leaflet=='top')
    %This means that the lipid bound to the top of the lipid
    b=strcat('top_',z,'.dat');
elseif(leaflet=='bot')
    b=strcat('bot_',z,'.dat');
else
    %something went wrong
end
A1=abs(importdata(b));
A2=A1(:,3);
A3=mean(A2);
tl=(ti*100+1):1:(tt*100+ti*100);

%plot(tl/100,o(i,ti*100+1:tt*100+ti*100))
clear A
clear A1

%%
%%%%%%%%%%%%%%%%%%        Plots for All Residues         %%%%%%%%%%%%%%%%%%
figure1=figure
for i=1:HHH/2
hold on
h(i)=plot(tl/100,o(i,ti*100+1:tt*100+ti*100), '-r' )
end
for i=((HHH/2)+1):HHH
hold on
h(i)=plot(tl/100,o(i,ti*100+1:tt*100+ti*100), '-k')
end
H=string(H);
temp=size(H);
H(1,(temp(1,2)+1))='P'
%plot(t, A3+t-t, '-g')
h(i+1)=plot(tl/100,A2(ti*100+1:tt*100+ti*100,1), '-g');
u='.txt'; v='.jpg'; u=strcat(z,u); v=strcat(z,'_All_Residues',v);
legend(h, H)
xlabel('Time (ns)');
title(strcat(z,' All Residues'))
xlim([ti ti+(2*(w-1)/a)])



ylabel('Z Position');
saveas(figure1,v);
hold off


L=mean(o(1:(HHH/2),ti*100+1:tt*100+ti*100));
LL=mean(o(((HHH/2)+1):HHH,ti*100+1:tt*100+ti*100));
figure1=figure
hold on
plot(tl/100,L, '-r')
plot(tl/100,LL,'-k')
%plot(t, A3+t-t, '-g')
plot(tl/100,A2(ti*100+1:tt*100+ti*100,1), '-g')
xlim([ti ti+(2*(w-1)/a)])
u='.jpg';
n='avg';
m=strcat(z,n);
m=strcat(m,u);
legend('Alpha-6 Half', 'Alpha-7 Half', 'Phosphate');
xlabel('Time (ns)');
ylabel('Z Position')
u=strcat(z,' Average of Alpha6 Alpha7');
title(u)
saveas(figure1,m);
hold off
clear L
clear LL
clear Ul
%%
%%%%%%%%%%%%%%%%%%%       Generating the data for the minimum       %%%%%%%%%%%%%%%%%%%%%%%%%
%H1 equals the organized data
H1=o;
clear o
%H1min goes through all the data and finds the minimum z position in each
%frame and stores it into H1min

H1min=min(H1(:,1));
for i=2:w
    H1min=[H1min min(H1(:,i))];
i=i+1;
end

%DMin created size--total number of resiudes by total number of frames
DMin=zeros(HHH,w);
%Here H1min is the global minimum the program tests to see if the global
%minimum matches the z value of this spicific residue at specific time of j
%When the criteria fails, which happens 11/12 times, it places a zero into
%the matrix

if(H1min(1,1)==H1(1,1))
    DMin(1,1)=H1(1,1);
else
    DMin(1,1)=0;
end

for j=1:w
    
for i=1:HHH
    if(H1min(1,j)==H1(i,j))
        DMin(i,j)=H1(i,j);
    else
        DMin(i,j)=0;
    end
    
end
end
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%    Deepest Residue Overall     %%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This is just some nameing stuff
u='.jpg';
%m=strcat('min',z, '.jpg');
m=strcat(m,u);

%I make another figure

%This just plots the Hmin values with time and then makes lines at zero 2.5
%5 and 7.5


figure1=figure;
plot(tl/100,H1min(1,ti*100+1:tt*100+ti*100), 'k')
hold on

%A5=size(A2)='total simulation time'
%A2(1,1)='total simuluation time
%Say that 
%if(ti>0)
%    A6=(size(A2)/100);
%    A6=A6(1,1)-ti;
%else
%    A6=(size(A2)/100);
%    A6=A6(1,1)-ti;
%end
%al=2*(A6*100-1)/100*tt;
%tl=(ti*100+1):1:(5000+ti*100);
plot(tl/100,A2(ti*100+1:tt*100+ti*100,1), 'g')
hold off

%A9=size(A2)
%A9=A9(1,1)
%c=D(1,2)/(A9-ti*100)


%A7(i,1)=A2(i,1)
%skip every 0.04th time 40/1000

xlim([ti ti+(2*(w-1)/a)])

legend('Deepest Residue', 'Phosphate Position')
xlabel('time (ns)')
ylabel('Z Position')
u=strcat(z,' Minimum Position');
title(u)
saveas(figure1,strcat(z,'Miminum Position.jpg'));
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%        Specific Residues being deepest Plotting               %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generating Minimum and frequency

%Searches through to find which values have minimum and stores them in a
%matrix called X
X=zeros(HHH,w);
for i=1:HHH
    for j=1:w
        if(DMin(i,j)>0)
            X(i,j)=1;
        end
    end
end

%Here it goes through every row and averages the entier row, stores it into
%matrix Y
Y=zeros(1,HHH);
Y(1,1)=mean(X(1,:));
for i=2:HHH
    Y(1,i)=mean(X(i,:));
end
%Creates 1 by 1 matrix Hnew and Hold
Hnew=zeros(1,1);
Hold=zeros(1,1);
j=1;
%Here it goes through the matrix of residue names and stores the actual
%residue id into matrix Hnew and a counger variable into Hold in order to
%color code the residues and keep track of which parts of the matrix have
%different residue data
for i=1:HHH
if(Y(1,i)>0 )
    Hnew(1,j)= (H(1,i));
    Hold(1,j)= i;
    j=j+1;
end
end

%B is the number of residues with minimums, not every residue has to have a
%minimum

B=size(Hold);
B=B(1,2);
%I'm creating a new figure
figure1=figure;
hold all
%This defines the colors that will be used to plot different residues:
%-----------------------------Important------------------------------------
%The first 7 colors are the primary matlab plotting colors, except for
%white. More than 12 residues choose colors wisely

c=[1 1 0 ;1 0 1 ; 0 1 1 ; 0 0 0; 0 0 1; 1 0 0;0 1 0 ; .6 .6 .6 ;.4 .2 .1 ;.9 .4 .1 ;.2 .3 .4 ;.9 .9 .9 ;];
clear h
for i=1:B

    %j is going over all the frames of organized data
    jj=ti*100;
    for j=ti:tt/wscatter:tt+ti
        jj=jj+1;
    %k much like i except it retains original position of the residues
    k=Hold(1,i);
        %if 
        if(DMin(k,jj)>0 )
        h(i)=plot(j,DMin(k,jj), '.', 'MarkerSize', 13, 'Color', c(k,:)) ;
        end
    end
end
h(i+1)=plot(tl/100,A2(ti*100+1:tt*100+ti*100,1), '-g');




%%i basically going over every residue
%for i=1:B
    %j is going over all the frames of organized data
   
%    for j=1:w
%    %k much like i except it retains original position of the residues
%    k=Hold(1,i);
%        %if 
%        if(DMin(k,j)>0 )
%        h(i)=plot((2*(j-1)/a)+ti,DMin(k,j), '.', 'MarkerSize', 13, 'Color', c(k,:)) ;
%        hold all
%        end
%    end
%end
%h(i+1)=plot(tl/100,A2(ti*100+1:tt*100+ti*100,1), '-g')

Hnew=string(Hnew);
temp=size(Hnew);
Hnew(1,(temp(1,2)+1))='P';

legend(h, Hnew)
xlim([ti ti+(2*(w-1)/a)])

title(strcat(z,' Deepest Residues Over Time'))
ylabel('Position of Deepest Residue')
xlabel('Time')

u=strcat(z,'Deepest.jpg');
saveas(figure1,u);
hold off

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%    This will plot based off VMD Convention %%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear c
%Neutral Non-Polar (White)      [1 1 1]
%G, A, V, I, W, F, P, M, L

for i=1:HHH
if(RNAME(1,i)=='G')     %Gly
    c(1,i)='w';
elseif(RNAME(1,i)=='A') %Ala
    c(1,i)='w';
elseif(RNAME(1,i)=='V') %Val
    c(1,i)='w';
elseif(RNAME(1,i)=='I') %Ile
    c(1,i)='w';
elseif(RNAME(1,i)=='W') %Trp
    c(1,i)='w';
elseif(RNAME(1,i)=='F') %Phe
    c(1,i)='w';
elseif(RNAME(1,i)=='P') %Pro
    c(1,i)='w';
elseif(RNAME(1,i)=='M') %Met
    c(1,i)='w';
elseif(RNAME(1,i)=='L') %Leu
    c(1,i)='w';
%Neutral Polar (Green)          [0 1 0]
%S, T, Y, N, Q, C
elseif(RNAME(1,i)=='S') %Ser
    c(1,i)='g';
elseif(RNAME(1,i)=='T') %Thr
    c(1,i)='g';
elseif(RNAME(1,i)=='Y') %Try
    c(1,i)='g';
elseif(RNAME(1,i)=='N') %Asn
    c(1,i)='g';
elseif(RNAME(1,i)=='Q') %Gln
    c(1,i)='g';
elseif(RNAME(1,i)=='C') %Cys
    c(1,i)='g';
%Acidic (Red)                   [1 0 0]
%D, E
elseif(RNAME(1,i)=='D') %Asp
    c(1,i)='r';
elseif(RNAME(1,i)=='E') %Glu
    c(1,i)='r';
%Basic (Blue)                   [ 0 0 1]
%K, R, H
elseif(RNAME(1,i)=='K') %Lys
    c(1,i)='b';
elseif(RNAME(1,i)=='R') %Arg
    c(1,i)='b';
elseif(RNAME(1,i)=='H') %His
    c(1,i)='b';
end
end
clear h
figure1=figure;
%i basically going over every residue

for i=1:B
    %j is going over all the frames of organized data

    jj=ti*100;
    for j=ti:tt/wscatter:tt+ti
        jj=jj+1;
    %k much like i except it retains original position of the residues
    k=Hold(1,i);
        %if 
        if(DMin(k,jj)>0 )
            set(gca, 'Color', 'k')
        h(i)=plot(j,DMin(k,jj), '.', 'MarkerSize', 13, 'Color', c(1,k)) ;
        hold all
        end
    end
end
h(i+1)=plot(tl/100,A2(ti*100+1:tt*100+ti*100,1), '-m');
legend(h, Hnew, 'TextColor','w')
xlim([ti ti+(2*(w-1)/a)])
title(strcat(z,' Deepest Residues Over Time'))
ylabel('Position of Deepest Residue')
xlabel('Time')
u=strcat(z,'DeepestVMD.jpg');
set(gcf,'InvertHardcopy','off');
saveas(gcf,u);
hold off



%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%        Frequency of being deepest Plotting        %%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%      Before Binding     %%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(bt>ti)
    
ratio=bt/(tt+ti);
w1=round(ratio*w);
n=num2str((w1/w)*(tt+ti));
n2=num2str(tt+ti);
n3=num2str(ti);
n4=strcat(n3, '-', n, '` ns');
n5=strcat(n, '-', n2, '` ns');

p=strcat(z,' Closest Residues Before Binding: `',n4);
X=zeros(HHH,w1);
for i=1:HHH
    for j=1:w1
        if(DMin(i,j)>0)
            X(i,j)=1;
        end
    end
end
Y=zeros(1,HHH);
Y(1,1)=mean(X(1,:));
for i=2:HHH
    Y(1,i)=mean(X(i,:));
end
figure1=figure;
H=Res1:Res2;
bar(H,Y)
xlabel('The Residue ID')
ylabel('Frequency')
title(p)


xlim([H(1,1)-.75, H(1,HHH)+.75])

u=strcat(z,'BeforeBinding_Histogram.jpg');
saveas(figure1,u);
hold off
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%           After Binding      %%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

X=zeros(HHH,w-w1);
for i=1:HHH
    for j=w1+1:w
        
        if(DMin(i,j)>0)
            X(i,j-w1)=1;
        end
    end
end
Y=zeros(1,HHH);
Y(1,1)=mean(X(1,:));
for i=2:HHH
    Y(1,i)=mean(X(i,:));
end

p=strcat(z, ' Deepest Residues After Binding: `', n5);
figure1=figure;
hold on
bar(H,Y)
xlabel('The Residue ID');
ylabel('Frequency');
title(p)
HHH=size(H);
HHH=HHH(1,2);

xlim([H(1,1)-.75, H(1,HHH)+.75])
u=strcat(z,'AfterBinding_Histogram.jpg');
saveas(figure1,u);

else
n=num2str((tt+ti));
n4=strcat('Time Frame', n, '` ns');

p=strcat(z,' Closest Residues During: `',n4);
X=zeros(HHH,w);
for i=1:HHH
    for j=1:w
        if(DMin(i,j)>0)
            X(i,j)=1;
        end
    end
end
Y=zeros(1,HHH);
Y(1,1)=mean(X(1,:));
for i=2:HHH
    Y(1,i)=mean(X(i,:));
end
figure1=figure;
bar(H,Y)
xlabel('The Residue ID')
ylabel('Frequency')
title(p)


xlim([H(1,1)-.75, H(1,HHH)+.75])

u=strcat(z,'BeforeBinding_Histogram.jpg');
saveas(figure1,u);
hold off

end


%%%%%%%%%%%%%%%%%%%%%First Closest %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for j=1:w1
    
for i=1:HHH
    if(H1min(1,j)==H1(i,j))
        DMin(i,j)=H1(i,j);
    else
        DMin(i,j)=0;
    end
    
end
end

X=zeros(HHH,w1);
for i=1:HHH
    for j=1:w1
        if(DMin(i,j)>0)
            X(i,j)=1;
        end
    end
end

%Here it goes through every row and averages the entier row, stores it into
%matrix Y
Y=zeros(1,HHH);
Y(1,1)=mean(X(1,:));
for i=2:HHH
    Y(1,i)=mean(X(i,:));
end
%Creates 1 by 1 matrix Hnew and Hold
Hnew=zeros(1,1);
Hold=zeros(1,1);
j=1;
%Here it goes through the matrix of residue names and stores the actual
%residue id into matrix Hnew and a counger variable into Hold in order to
%color code the residues and keep track of which parts of the matrix have
%different residue data
for i=1:HHH
if(Y(1,i)>0 )
    Hnew(1,j)= (H(1,i));
    Hold(1,j)= i;
    j=j+1;
end
end

%%%%%%%%%%%%

%%%%for second closest
H2=H1;
for j=1:w1
for i=1:HHH
if(min(H2(:,j))==H2(i,j))
H2(i,j)=H2(i,j)+10;
j;
end
end
end

H2min=min(H2(:,1));
for i=2:w1
    H2min=[H2min min(H2(:,i))];
i=i+1;
end


for j=1:w1
for i=1:HHH
    if(H2min(1,j)==H2(i,j))
        D2Min(i,j)=H2(i,j);
    else
        D2Min(i,j)=0;
    end
    
end
end
%%%%For Second closest


X2=zeros(HHH,w1);
for i=1:HHH
    for j=1:w1
        if(D2Min(i,j)>0)
            X2(i,j)=1;
        end
    end
end

%Here it goes through every row and averages the entier row, stores it into
%matrix Y
Y2=zeros(1,HHH);
Y2(1,1)=mean(X2(1,:));
for i=2:HHH
    Y2(1,i)=mean(X2(i,:));
end
%Creates 1 by 1 matrix Hnew and Hold
H2new=zeros(1,1);
H2old=zeros(1,1);
j=1;
%Here it goes through the matrix of residue names and stores the actual
%residue id into matrix Hnew and a counger variable into Hold in order to
%color code the residues and keep track of which parts of the matrix have
%different residue data
for i=1:HHH
if(Y2(1,i)>0 )
    H2new(1,j)= (H2(1,i));
    H2old(1,j)= i;
    j=j+1;
end
end

B2=size(H2old);
B2=B2(1,2);

%B is the number of residues with minimums, not every residue has to have a
%minimum

Z=zeros(12,12);
for j=1:w1
for i=1:HHH
for k=1:HHH  
if(X(i,j)==X2(k,j))
    if(X(i,j)>0)
        if(X2(k,j)>0)
            Z(i,k)=Z(i,k)+1;
end
end
end
end
end
end
ZZ=zeros(1,12*12);

for i=1:HHH
    for j=1:HHH
        ZZ(1,j+((i-1)*HHH))=Z(i,j);
    end
end

j=1;
for i=1:HHH*HHH
    ZZ(1,i)=ZZ(1,i)/(15075*bt/tt);
    if(ZZ(1,i)>0)
        k(1,j)=i;
        j=j+1;
    end
end

    %1-12 is 321 first one of others second
    %13-22 is 322 first one of others second
    %23-32 is 323 first on of others second


RID=Res1:Res2;
r=1;
clear box
kk=size(k);
kk=kk(1,2);
for i=1:HHH
    for j=1:HHH
        if(r==kk+1)
            i=HHH;
            j=HHH;
        else
            if(j+((i-1)*HHH)==k(1,r))
                if(r==1)
                    box=[strcat(string(RID(1,i)),'-', string(RID(1,j)))];
                    r=r+1;
                else
                    box=[box strcat(string(RID(1,i)),'-', string(RID(1,j)))];
                    r=r+1;
                end
            end
        end
    end
end


for i=1:kk
    ZZZ(1,i)=ZZ(1,k(1,i));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p=strcat(z,' Closest Residues Before Binding: `',n4);
figure1=figure;
bar(ZZZ)
set(gca, 'XTickLabel', box, 'XTick', 1:numel(box), 'FontSize', 8)
xlabel('The Residue ID')
ylabel('Frequency')
title(p)
u=strcat(z,'BeforeBinding_Histogram');
saveas(figure1,strcat(u,'second'));
hold off
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%           After Binding      %%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear ZZZ
for j=1+w1:w
    
for i=1:HHH
    if(H1min(1,j)==H1(i,j))
        DMin(i,j)=H1(i,j);
    else
        DMin(i,j)=0;
    end
    
end
end

X=zeros(HHH,w-w1);
for i=1:HHH
    for j=w1+1:w
        if(DMin(i,j)>0)
            X(i,j)=1;
        end
    end
end

%Here it goes through every row and averages the entier row, stores it into
%matrix Y
Y=zeros(1,HHH);
Y(1,1)=mean(X(1,:));
for i=2:HHH
    Y(1,i)=mean(X(i,:));
end
%Creates 1 by 1 matrix Hnew and Hold
Hnew=zeros(1,1);
Hold=zeros(1,1);
j=1;
%Here it goes through the matrix of residue names and stores the actual
%residue id into matrix Hnew and a counger variable into Hold in order to
%color code the residues and keep track of which parts of the matrix have
%different residue data
for i=1:HHH
if(Y(1,i)>0 )
    Hnew(1,j)= (H(1,i));
    Hold(1,j)= i;
    j=j+1;
end
end

%%%%%%%%%%%%

%%%%for second closest
H2=H1;
for j=w1+1:w
for i=1:HHH
if(min(H2(:,j))==H2(i,j))
H2(i,j)=H2(i,j)+10;
j;
end
end
end


for i=w1+1:w
    if(i==w1)
        H2min=[min(H2(:,i))];
    else
        H2min=[H2min min(H2(:,i))];
i=i+1;
end
end

for j=w1+1:w
for i=1:HHH
    if(H2min(1,j)==H2(i,j))
        D2Min(i,j)=H2(i,j);
    else
        D2Min(i,j)=0;
    end
    
end
end
%%%%For Second closest


X2=zeros(HHH,w-w1);
for i=1:HHH
    for j=w1+1:w
        if(D2Min(i,j)>0)
            X2(i,j)=1;
        end
    end
end

%Here it goes through every row and averages the entier row, stores it into
%matrix Y
Y2=zeros(1,HHH);
Y2(1,1)=mean(X2(1,:));
for i=2:HHH
    Y2(1,i)=mean(X2(i,:));
end
%Creates 1 by 1 matrix Hnew and Hold
H2new=zeros(1,1);
H2old=zeros(1,1);
j=1;
%Here it goes through the matrix of residue names and stores the actual
%residue id into matrix Hnew and a counger variable into Hold in order to
%color code the residues and keep track of which parts of the matrix have
%different residue data
for i=1:HHH
if(Y2(1,i)>0 )
    H2new(1,j)= (H2(1,i));
    H2old(1,j)= i;
    j=j+1;
end
end

B2=size(H2old);
B2=B2(1,2);

%B is the number of residues with minimums, not every residue has to have a
%minimum

B=size(Hold);
B=B(1,2);



Z=zeros(12,12);
for j=w1+1:w
for i=1:HHH
for k=1:HHH
if(X(i,j)==X2(k,j))
    if(X(i,j)>0)
        if(X2(k,j)>0)
            Z(i,k)=Z(i,k)+1;
end
end
end
end
end
end
ZZ=zeros(1,12*12);

for i=1:HHH
    for j=1:HHH
        ZZ(1,j+((i-1)*HHH))=Z(i,j);
    end
end


j=1;
for i=1:HHH*HHH
    ZZ(1,i)=ZZ(1,i)/(15075*(1-(bt/tt)));
    if(ZZ(1,i)>0)
        k(1,j)=i;
        j=j+1;
    end
end

    %1-12 is 321 first one of others second
    %13-22 is 322 first one of others second
    %23-32 is 323 first on of others second


RID=Res1:Res2;
r=1;
clear box
kk=size(k);
kk=kk(1,2);
for i=1:HHH
    for j=1:HHH
        if(r==kk+1)
            i=HHH;
            j=HHH;
        else
            if(j+((i-1)*HHH)==k(1,r))
                if(r==1)
                    box=[strcat(string(RID(1,i)),'-', string(RID(1,j)))];
                    r=r+1;
                else
                    box=[box strcat(string(RID(1,i)),'-', string(RID(1,j)))];
                    r=r+1;
                end
            end
        end
    end
end


for i=1:kk
    ZZZ(1,i)=ZZ(1,k(1,i));
end


p=strcat(z, ' Deepest Residues After Binding: `', n5);
figure1=figure;
hold on
bar(ZZZ)
set(gca, 'XTickLabel', box, 'XTick', 1:numel(box), 'FontSize', 8)
xlabel('The Residue ID')
ylabel('Frequency')
title(p)
HHH=size(H);
HHH=HHH(1,2);


u=strcat(z,'AfterBinding_Histogram');
saveas(figure1,strcat(u,'second'));
    

end
